"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.alphaNumericDash = exports.alphaNumeric = exports.alphaHyphen = exports.alphaDash = exports.alpha = void 0;
const REGEX_ALPHA = /^[A-Z]+$/i;
const REGEX_ALPHA_DASH = /^[A-Z_-]+$/i;
const REGEX_ALPHA_HYPHEN = /^[A-Z-]+$/i;
const REGEX_ALPHA_NUMERIC = /^[0-9A-Z]+$/i;
const REGEX_ALPHA_NUMERIC_DASH = /^[A-Z0-9_-]+$/i;
/**
 * The field under validation must be entirely alphabetic characters.
 */
function alpha() {
    return {
        name: "alpha",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return REGEX_ALPHA.test(value);
        },
    };
}
exports.alpha = alpha;
/**
 * The field under validation may have alpha characters, as well as hyphens and underscores.
 */
function alphaDash() {
    return {
        name: "alphaDash",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return REGEX_ALPHA_DASH.test(value);
        },
    };
}
exports.alphaDash = alphaDash;
/**
 * The field under validation may have alpha characters, as well as hyphens.
 */
function alphaHyphen() {
    return {
        name: "alphaHyphen",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return REGEX_ALPHA_HYPHEN.test(value);
        },
    };
}
exports.alphaHyphen = alphaHyphen;
/**
 * The field under validation must contains alpha-numeric characters.
 */
function alphaNumeric() {
    return {
        name: "alphaNumeric",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return REGEX_ALPHA_NUMERIC.test(value);
        },
    };
}
exports.alphaNumeric = alphaNumeric;
/**
 * The field under validation may have alpha-numeric characters, as well as hyphens and underscores.
 */
function alphaNumericDash() {
    return {
        name: "alphaNumericDash",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return REGEX_ALPHA_NUMERIC_DASH.test(value);
        },
    };
}
exports.alphaNumericDash = alphaNumericDash;
//# sourceMappingURL=alpha.rule.js.map