"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.between = void 0;
const number_util_1 = require("../utils/number.util");
/**
 * The field under validation must be between min and max seed.
 * This will work with number as well as array.
 * In case of array, array values must be numbers between min and max seed.
 * @param args seeds
 */
function between(args) {
    if (args.length !== 2) {
        throw new Error('Invalid number of arguments.');
    }
    if (!number_util_1.isNumeric(args[0]) || !number_util_1.isNumeric(args[0])) {
        throw new TypeError('Seeds must be number.');
    }
    const min = Number(args[0]);
    const max = Number(args[1]);
    if (min >= max) {
        throw new RangeError('Seed min must be less then max.');
    }
    return {
        name: 'between',
        handler: (value) => {
            if (Array.isArray(value)) {
                let i = 0;
                const len = value.length;
                for (i; i < len; i++) {
                    const v = String(value[i]);
                    if (!number_util_1.isNumeric(v)) {
                        return false;
                    }
                }
                const minV = Math.min(...value);
                const maxV = Math.max(...value);
                if (minV < min || maxV > max) {
                    return false;
                }
                return true;
            }
            const v = String(value);
            if (!number_util_1.isNumeric(v)) {
                return false;
            }
            const valNum = Number(value);
            if (valNum < min || valNum > max) {
                return false;
            }
            return true;
        },
    };
}
exports.between = between;
//# sourceMappingURL=between.rule.js.map