"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.date = exports.datetime = exports.dateISO = exports.dateFormat = exports.dateBeforeToday = exports.before = exports.dateBefore = exports.dateAfterToday = exports.after = exports.dateAfter = void 0;
const date_1 = require("../date");
function dateAfter(args) {
    if (args.length !== 2) {
        throw new Error('Rule accepts 2 argument (format,date).');
    }
    const adapter = date_1.dateAdapter();
    const [format, dateToCompare] = args;
    if (typeof format !== 'string') {
        throw new TypeError('First element must be date format.');
    }
    return {
        name: "dateAfter",
        handler: (value) => {
            return adapter.isAfter(format, value, dateToCompare || new Date);
        },
    };
}
exports.dateAfter = dateAfter;
function after(args) {
    if (!args.length || args.length > 2) {
        throw new Error('Rule accepts 2 argument (format,[date optional]).');
    }
    const adapter = date_1.dateAdapter();
    const [format, dateToCompare] = args;
    if (typeof format !== 'string') {
        throw new TypeError('First element must be date format.');
    }
    return {
        name: "after",
        handler: (value) => {
            return adapter.isAfter(format, value, dateToCompare || new Date());
        },
    };
}
exports.after = after;
function dateAfterToday(args) {
    if (args.length !== 1) {
        throw new Error('Rule accepts only 1 argument (format).');
    }
    const adapter = date_1.dateAdapter();
    const [format] = args;
    return {
        name: "dateAfterToday",
        handler: (value) => {
            return adapter.isAfter(format, value, new Date);
        },
    };
}
exports.dateAfterToday = dateAfterToday;
function dateBefore(args) {
    if (args.length !== 2) {
        throw new Error('Rule accepts 2 argument (format,date).');
    }
    const adapter = date_1.dateAdapter();
    const [format, dateToCompare] = args;
    if (typeof format !== 'string') {
        throw new TypeError('First element must be date format.');
    }
    return {
        name: "dateBefore",
        handler: (value) => {
            return adapter.isBefore(format, value, dateToCompare);
        },
    };
}
exports.dateBefore = dateBefore;
function before(args) {
    if (!args.length || args.length > 2) {
        throw new Error('Rule accepts 2 argument (format,[date optional]).');
    }
    const adapter = date_1.dateAdapter();
    const [format, dateToCompare] = args;
    if (typeof format !== 'string') {
        throw new TypeError('First element must be date format.');
    }
    return {
        name: "before",
        handler: (value) => {
            return adapter.isBefore(format, value, dateToCompare || new Date());
        },
    };
}
exports.before = before;
function dateBeforeToday(args) {
    if (args.length !== 1) {
        throw new Error('Rule accepts only 1 argument (format).');
    }
    const adapter = date_1.dateAdapter();
    const [format] = args;
    return {
        name: "dateBeforeToday",
        handler: (value) => {
            return adapter.isBefore(format, value, new Date);
        },
    };
}
exports.dateBeforeToday = dateBeforeToday;
function dateFormat(args) {
    if (args.length !== 1) {
        throw new Error('Rule accepts only 1 argument (format).');
    }
    const [format] = args;
    const adapter = date_1.dateAdapter();
    return {
        name: "dateFormat",
        handler: (value) => {
            return adapter.isValidDateFormat(value, format);
        },
    };
}
exports.dateFormat = dateFormat;
function dateISO() {
    const adapter = date_1.dateAdapter();
    return {
        name: "dateISO",
        handler: (value) => {
            return adapter.isValidIsoDateFormat(value);
        },
    };
}
exports.dateISO = dateISO;
// export { dateISO as dateiso, dateISO as iso8601 };
function datetime() {
    const adapter = date_1.dateAdapter();
    return {
        name: 'datetime',
        handler: (value) => {
            return adapter.isValidDateFormat(value, adapter.FORMAT_DATETIME);
        }
    };
}
exports.datetime = datetime;
function date(args = []) {
    const adapter = date_1.dateAdapter();
    const [format = adapter.FORMAT_DATE] = args;
    return {
        name: 'date',
        handler: (value) => {
            return adapter.isValidDateFormat(value, format);
        }
    };
}
exports.date = date;
//# sourceMappingURL=date.rule.js.map