"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.base64 = exports.json = exports.ascii = void 0;
const asciiRegex = /^[\x00-\x7F]+$/;
function ascii() {
    return {
        name: "ascii",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return asciiRegex.test(value);
        },
    };
}
exports.ascii = ascii;
function json() {
    return {
        name: "json",
        handler: (value) => {
            try {
                const obj = JSON.parse(value);
                return !!obj && typeof obj === 'object';
            }
            catch (e) {
                /* ignore */
            }
            return false;
        },
    };
}
exports.json = json;
const notBase64 = /[^A-Z0-9+\/=]/i;
const urlSafeBase64 = /^[A-Z0-9_\-]*$/i;
function base64(args = []) {
    return {
        name: "base64",
        handler: (value) => {
            const len = value.length;
            if (args && args[0] === 'urlsafe') {
                return urlSafeBase64.test(value);
            }
            if (len % 4 !== 0 || notBase64.test(value)) {
                return false;
            }
            const firstPaddingChar = value.indexOf('=');
            return firstPaddingChar === -1 ||
                firstPaddingChar === len - 1 ||
                (firstPaddingChar === len - 2 && value[len - 1] === '=');
        },
    };
}
exports.base64 = base64;
//# sourceMappingURL=encoding.rule.js.map