const REGEX_ALPHA = /^[A-Z]+$/i;
const REGEX_ALPHA_DASH = /^[A-Z_-]+$/i;
const REGEX_ALPHA_HYPHEN = /^[A-Z-]+$/i;
const REGEX_ALPHA_NUMERIC = /^[0-9A-Z]+$/i;
const REGEX_ALPHA_NUMERIC_DASH = /^[A-Z0-9_-]+$/i;
/**
 * The field under validation must be entirely alphabetic characters.
 */
export function alpha() {
    return {
        name: "alpha",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return REGEX_ALPHA.test(value);
        },
    };
}
/**
 * The field under validation may have alpha characters, as well as hyphens and underscores.
 */
export function alphaDash() {
    return {
        name: "alphaDash",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return REGEX_ALPHA_DASH.test(value);
        },
    };
}
/**
 * The field under validation may have alpha characters, as well as hyphens.
 */
export function alphaHyphen() {
    return {
        name: "alphaHyphen",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return REGEX_ALPHA_HYPHEN.test(value);
        },
    };
}
/**
 * The field under validation must contains alpha-numeric characters.
 */
export function alphaNumeric() {
    return {
        name: "alphaNumeric",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return REGEX_ALPHA_NUMERIC.test(value);
        },
    };
}
/**
 * The field under validation may have alpha-numeric characters, as well as hyphens and underscores.
 */
export function alphaNumericDash() {
    return {
        name: "alphaNumericDash",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return REGEX_ALPHA_NUMERIC_DASH.test(value);
        },
    };
}
//# sourceMappingURL=alpha.rule.js.map