import { dateAdapter } from "../date";
export function dateAfter(args) {
    if (args.length !== 2) {
        throw new Error('Rule accepts 2 argument (format,date).');
    }
    const adapter = dateAdapter();
    const [format, dateToCompare] = args;
    if (typeof format !== 'string') {
        throw new TypeError('First element must be date format.');
    }
    return {
        name: "dateAfter",
        handler: (value) => {
            return adapter.isAfter(format, value, dateToCompare || new Date);
        },
    };
}
export function after(args) {
    if (!args.length || args.length > 2) {
        throw new Error('Rule accepts 2 argument (format,[date optional]).');
    }
    const adapter = dateAdapter();
    const [format, dateToCompare] = args;
    if (typeof format !== 'string') {
        throw new TypeError('First element must be date format.');
    }
    return {
        name: "after",
        handler: (value) => {
            return adapter.isAfter(format, value, dateToCompare || new Date());
        },
    };
}
export function dateAfterToday(args) {
    if (args.length !== 1) {
        throw new Error('Rule accepts only 1 argument (format).');
    }
    const adapter = dateAdapter();
    const [format] = args;
    return {
        name: "dateAfterToday",
        handler: (value) => {
            return adapter.isAfter(format, value, new Date);
        },
    };
}
export function dateBefore(args) {
    if (args.length !== 2) {
        throw new Error('Rule accepts 2 argument (format,date).');
    }
    const adapter = dateAdapter();
    const [format, dateToCompare] = args;
    if (typeof format !== 'string') {
        throw new TypeError('First element must be date format.');
    }
    return {
        name: "dateBefore",
        handler: (value) => {
            return adapter.isBefore(format, value, dateToCompare);
        },
    };
}
export function before(args) {
    if (!args.length || args.length > 2) {
        throw new Error('Rule accepts 2 argument (format,[date optional]).');
    }
    const adapter = dateAdapter();
    const [format, dateToCompare] = args;
    if (typeof format !== 'string') {
        throw new TypeError('First element must be date format.');
    }
    return {
        name: "before",
        handler: (value) => {
            return adapter.isBefore(format, value, dateToCompare || new Date());
        },
    };
}
export function dateBeforeToday(args) {
    if (args.length !== 1) {
        throw new Error('Rule accepts only 1 argument (format).');
    }
    const adapter = dateAdapter();
    const [format] = args;
    return {
        name: "dateBeforeToday",
        handler: (value) => {
            return adapter.isBefore(format, value, new Date);
        },
    };
}
export function dateFormat(args) {
    if (args.length !== 1) {
        throw new Error('Rule accepts only 1 argument (format).');
    }
    const [format] = args;
    const adapter = dateAdapter();
    return {
        name: "dateFormat",
        handler: (value) => {
            return adapter.isValidDateFormat(value, format);
        },
    };
}
export function dateISO() {
    const adapter = dateAdapter();
    return {
        name: "dateISO",
        handler: (value) => {
            return adapter.isValidIsoDateFormat(value);
        },
    };
}
// export { dateISO as dateiso, dateISO as iso8601 };
export function datetime() {
    const adapter = dateAdapter();
    return {
        name: 'datetime',
        handler: (value) => {
            return adapter.isValidDateFormat(value, adapter.FORMAT_DATETIME);
        }
    };
}
export function date(args = []) {
    const adapter = dateAdapter();
    const [format = adapter.FORMAT_DATE] = args;
    return {
        name: 'date',
        handler: (value) => {
            return adapter.isValidDateFormat(value, format);
        }
    };
}
//# sourceMappingURL=date.rule.js.map