import { isDecimal, isInt, isNumeric } from '../utils/number.util';
export function integer(args = []) {
    return {
        name: "integer",
        handler: (value) => {
            return isInt(value + "", args && args[0] === '0');
        },
    };
}
export function min(args) {
    if (args.length !== 1) {
        throw new Error('Invalid number of arguments.');
    }
    const minNum = Number(args[0]);
    if (isNaN(minNum)) {
        throw new TypeError('Seed must be number.');
    }
    return {
        name: "min",
        handler: (value) => {
            const v = String(value);
            if (!isNumeric(v)
                || Number(v) < minNum) {
                return false;
            }
            return true;
        },
    };
}
export function max(args) {
    if (args.length !== 1) {
        throw new Error('Invalid number of arguments.');
    }
    const maxNum = Number(args[0]);
    if (isNaN(maxNum)) {
        throw new TypeError('Seed must be number.');
    }
    return {
        name: "max",
        handler: (value) => {
            const v = String(value);
            if (!isNumeric(v)
                || Number(v) > maxNum) {
                return false;
            }
            return true;
        },
    };
}
export function decimal() {
    return {
        name: "decimal",
        handler: (value) => {
            if (typeof value !== 'string') {
                return false;
            }
            return isDecimal(value);
        },
    };
}
export function numeric() {
    return {
        name: "numeric",
        handler: (value) => {
            return isNumeric(value + "");
        },
    };
}
//# sourceMappingURL=number.rule.js.map